@@ -7,8 +7,12 @@ use Test::BDD::Infrastructure::File;
 use Test::BDD::Infrastructure::Process;
 use Test::BDD::Infrastructure::HTTP;
 use Test::BDD::Infrastructure::Compare;
+use Test::BDD::Infrastructure::DNS;
+use Test::BDD::Infrastructure::Filesystem;
+use Test::BDD::Infrastructure::Swap;
+use Test::BDD::Infrastructure::Socket;
 
-our $VERSION = '1.001'; # VERSION
+our $VERSION = '1.002'; # VERSION
 # ABSTRACT: a collection of step file definitions for Test Driven Infrastructure
 
 
@@ -26,13 +30,21 @@ Test::BDD::Infrastructure - a collection of step file definitions for Test Drive
 
 =head1 VERSION
 
-version 1.001
+version 1.002
 
 =head1 Description
 
 This is a collection of generic step definitions for infrastructure testing
 with Test::BDD::Cucumber.
 
+=head1 What is Test Driven Infrastructure?
+
+TDI takes the concept of Test Driven Development used for software development
+and applies it to infrastructure.
+
+Instead of software it is used to test infrastructure.
+Instead of function and classes it is used to test daemons and configuration.
+
 =head1 Overview
 
 =over
@@ -42,6 +54,11 @@ with Test::BDD::Cucumber.
 Checks for testing existence, attributes, size, mode
 and content of files and directories.
 
+=item L<Test::BDD::Infrastructure::DNS>
+
+Checks for constructing DNS queries and checking response
+and records.
+
 =item L<Test::BDD::Infrastructure::Process>
 
 Checks for testing the process table.
@@ -54,6 +71,18 @@ Checks for testing a HTTP server.
 
 Checks for testing configuration variables.
 
+=item L<Test::BDD::Infrastructure::Filesystem>
+
+Checks for testing file system usage.
+
+=item L<Test::BDD::Infrastructure::Swap>
+
+Check for testing swap space usage.
+
+=item L<Test::BDD::Infrastructure::Socket>
+
+Checks for tcp/udp/unix-socket based checks.
+
 =back
 
 =head1 Example
@@ -69,6 +98,7 @@ Or just include individual steps:
   use Test::BDD::Infrastructure::File;
   use Test::BDD::Infrastructure::HTTP;
   use Test::BDD::Infrastructure::Process;
+  ...
 
 Then define features of your infrastructure:
 
@@ -78,29 +108,29 @@ Then define features of your infrastructure:
   is configured and running.
 
   Scenario: The webserver process must be running
-  Given a parent process like ^/usr/sbin/apache2.prefork is running
-  Then the uid of the process must be root
-  And the gid of the process must be root
-  And the RSS size of the process must be smaller than 32 megabyte
-  When there are at least 5 child processes like ^/usr/sbin/apache2.prefork
-  Then the uid of the child processes must be www-data
-  And the gid of the child processes must be www-data
-  And the RSS size of the child processes must be smaller than 64 megabyte
+    Given a parent process like ^/usr/sbin/apache2.prefork is running
+    Then the uid of the process must be root
+    And the gid of the process must be root
+    And the RSS size of the process must be smaller than 32 megabyte
+    When there are at least 5 child processes like ^/usr/sbin/apache2.prefork
+    Then the uid of the child processes must be www-data
+    And the gid of the child processes must be www-data
+    And the RSS size of the child processes must be smaller than 64 megabyte
 
   Scenario: The start page of the webserver must be accessible
-  Given the http URL http://www.example.mydomain.de/
-  When the http request is sent
-  Then the http response must be successfull
-  And the http response header Content-Type must be like text/html
-  And the http response content must be like Welcome to Example
+    Given the http URL http://www.example.mydomain.de/
+    When the http request is sent
+    Then the http response must be successfull
+    And the http response header Content-Type must be like text/html
+    And the http response content must be like Welcome to Example
 
   Scenario: The webserver must log access
-  Given the file /var/log/apache2/access.log exists
-  Then the file mode must be 0640
-  And the file must be owned by user root
-  And the file must be owned by group adm
-  And the file must contain at least 1 line
-  And the file mtime must be newer than 5 minutes
+    Given the file /var/log/apache2/access.log exists
+    Then the file mode must be 0640
+    And the file must be owned by user root
+    And the file must be owned by group adm
+    And the file must contain at least 1 line
+    And the file mtime must be newer than 5 minutes
 
 =head1 See also
 
