@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 # ABSTRACT: class with collection of some utility functions
-our $VERSION = '1.001'; # VERSION
+our $VERSION = '1.002'; # VERSION
 
 our (@ISA, @EXPORT_OK);
 
@@ -53,16 +53,29 @@ sub convert_cmp_operator {
 
 
 our $UNITS = {
+	'%' => 0.01,
+	percent => 0.01,
+
 	byte => 1,
 	b => 1,
-	kilobyte => 1024,
-	kb => 1024,
-	megabyte => 1024*1024,
-	mb => 1024*1024,
-	gigabyte => 1024*1024*1024,
-	gb => 1024*1024*1024,
-	terrabyte => 1024*1024*1024*1024,
-	tb => 1024*1024*1024*1024,
+
+	kilobyte => 1000,
+	kb => 1000,
+	megabyte => 1000000,
+	mb => 1000000,
+	gigabyte => 1000000000,
+	gb => 1000000000,
+	terrabyte => 1000000000000,
+	tb => 1000000000000,
+
+	kibibyte => 1024,
+	kib => 1024,
+	mebibyte => 1024*1024,
+	mib => 1024*1024,
+	gibibyte => 1024*1024*1024,
+	gib => 1024*1024*1024,
+	tebibyte => 1024*1024*1024*1024,
+	tib => 1024*1024*1024*1024,
 };
 
 sub convert_unit {
@@ -159,7 +172,7 @@ Test::BDD::Infrastructure::Utils - class with collection of some utility functio
 
 =head1 VERSION
 
-version 1.001
+version 1.002
 
 =head1 Human readable operators
 
@@ -231,16 +244,46 @@ Returns the size in bytes.
 
 =over
 
+=item percent, %
+
+1/100
+
 =item byte, b
 
+1 byte
+
 =item kilobyte, kb
 
+1000 byte
+
 =item megabyte, mb
 
+1000000 byte
+
 =item gigabyte, gb
 
+1000000000 byte
+
 =item terrabyte, tb
 
+1000000000000 byte
+
+=item kibibyte, kib
+
+1024 byte
+
+=item mebibyte, mib
+
+1048576 byte
+
+=item gibibyte, gib
+
+1073741824 byte
+
+=item tebibyte, tb
+
+1099511627776 byte
+
 =back
 
 =head1 Intervals
